==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebSliderBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderBaseDescription } from "./WebSliderBaseDescription";
/**
 * @hidden
 */
var WebSliderBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderBaseDescriptionMetadata, _super);
    function WebSliderBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderBaseDescriptionMetadata.b = function (a) {
        if (WebSliderBaseDescriptionMetadata.a == null) {
            WebSliderBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderBaseDescriptionMetadata.c(WebSliderBaseDescriptionMetadata.a);
        }
        if (a.g(WebSliderBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(WebSliderBaseDescriptionMetadata.a);
    };
    WebSliderBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SliderBase");
        a.item("Min", "Number:double");
        a.item("Max", "Number:double");
        a.item("LowerBound", "Number:double");
        a.item("UpperBound", "Number:double");
        a.item("Disabled", "Boolean");
        a.item("DiscreteTrack", "Boolean");
        a.item("HideTooltip", "Boolean");
        a.item("Step", "Number:double");
        a.item("PrimaryTicks", "Number:double");
        a.item("SecondaryTicks", "Number:double");
        a.item("TickOrientation", "ExportedType:string:SliderBaseTickOrientation");
        a.item("TickOrientation@names", "Start;End;Mirror");
        a.item("HidePrimaryLabels", "Boolean");
        a.item("HideSecondaryLabels", "Boolean");
        a.item("Locale", "String");
        a.item("ValueFormat", "String");
        a.item("ValueFormatOptions", "ExportedType");
        a.item("TickLabelRotation", "ExportedType:string:TickLabelRotation");
        a.item("TickLabelRotation@names", "Zero;Ninety;NegativeNinety");
    };
    WebSliderBaseDescriptionMetadata.d = function (a) {
        WebSliderBaseDescriptionMetadata.b(a);
        a.u("WebSliderBase", function () { return new WebSliderBaseDescription(); });
        a.t("WebSliderBase", WebSliderBaseDescriptionMetadata.a);
    };
    WebSliderBaseDescriptionMetadata.$t = markType(WebSliderBaseDescriptionMetadata, 'WebSliderBaseDescriptionMetadata');
    WebSliderBaseDescriptionMetadata.a = null;
    return WebSliderBaseDescriptionMetadata;
}(Base));
export { WebSliderBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSliderBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderBaseDescription } from "./WebSliderBaseDescription";
/**
 * @hidden
 */
var WebSliderBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSliderBaseDescriptionMetadata, _super);
    function WebSliderBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSliderBaseDescriptionMetadata.b = function (a) {
        if (WebSliderBaseDescriptionMetadata.a == null) {
            WebSliderBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSliderBaseDescriptionMetadata.c(WebSliderBaseDescriptionMetadata.a);
        }
        if (a.j(WebSliderBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSliderBaseDescriptionMetadata.a);
    };
    WebSliderBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SliderBase");
        a.item("__tagNameWC", "String:igc-slider-base");
        a.item("Min", "Number:double");
        a.item("Max", "Number:double");
        a.item("LowerBound", "Number:double");
        a.item("UpperBound", "Number:double");
        a.item("Disabled", "Boolean");
        a.item("DiscreteTrack", "Boolean");
        a.item("HideTooltip", "Boolean");
        a.item("Step", "Number:double");
        a.item("PrimaryTicks", "Number:double");
        a.item("SecondaryTicks", "Number:double");
        a.item("TickOrientation", "ExportedType:string:SliderBaseTickOrientation");
        a.item("TickOrientation@names", "Start;End;Mirror");
        a.item("HidePrimaryLabels", "Boolean");
        a.item("HideSecondaryLabels", "Boolean");
        a.item("Locale", "String");
        a.item("ValueFormat", "String");
        a.item("ValueFormatOptions", "ExportedType");
        a.item("TickLabelRotation", "ExportedType:string:TickLabelRotation");
        a.item("TickLabelRotation@names", "Zero;Ninety;NegativeNinety");
    };
    WebSliderBaseDescriptionMetadata.d = function (a) {
        WebSliderBaseDescriptionMetadata.b(a);
        a.aa("WebSliderBase", function () { return new WebSliderBaseDescription(); });
        a.z("WebSliderBase", WebSliderBaseDescriptionMetadata.a);
    };
    WebSliderBaseDescriptionMetadata.$t = markType(WebSliderBaseDescriptionMetadata, 'WebSliderBaseDescriptionMetadata');
    WebSliderBaseDescriptionMetadata.a = null;
    return WebSliderBaseDescriptionMetadata;
}(Base));
export { WebSliderBaseDescriptionMetadata };
